@@ -31,6 +31,14 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Exit instead"]
 
+exception Not_found
+[@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Instead of raising [Not_found], consider using [raise_s] with an informative error
+message.  If code needs to distinguish [Not_found] from other exceptions, please change
+it to handle both [Not_found] and [Not_found_s].  Then, instead of raising [Not_found],
+raise [Not_found_s] with an informative error message."]
+
 external ( = ) : 'a -> 'a -> bool = "%equal"
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -107,24 +115,12 @@ external ( && ) : bool -> bool -> bool = "%sequand"
 There is not equivalent functionality in Base or Stdio at the moment,
 so you need to use [Caml.( && )] instead"]
 
-external ( & ) : bool -> bool -> bool = "%sequand"
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-There is not equivalent functionality in Base or Stdio at the moment,
-so you need to use [Caml.( & )] instead"]
-
 external ( || ) : bool -> bool -> bool = "%sequor"
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
 There is not equivalent functionality in Base or Stdio at the moment,
 so you need to use [Caml.( || )] instead"]
 
-external ( or ) : bool -> bool -> bool = "%sequor"
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-There is not equivalent functionality in Base or Stdio at the moment,
-so you need to use [Caml.( or )] instead"]
-
 external __LOC__ : string = "%loc_LOC"
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1070,6 +1066,12 @@ val do_at_exit : unit -> unit
 There is not equivalent functionality in Base or Stdio at the moment,
 so you need to use [Caml.do_at_exit] instead"]
 
+val do_domain_local_at_exit : (unit -> unit) ref
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+There is not equivalent functionality in Base or Stdio at the moment,
+so you need to use [Caml.do_domain_local_at_exit] instead"]
+
 module Arg = Stdlib.Arg 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1147,6 +1149,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Complex instead"]
 
+module Condition = Stdlib.Condition 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Condition instead"]
+
 module Digest = Stdlib.Digest 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1154,6 +1163,20 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Digest instead"]
 
+module Domain = Stdlib.Domain 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Domain instead"]
+
+module Effect = Stdlib.Effect 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Effect instead"]
+
 module Either = Stdlib.Either 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1200,13 +1223,6 @@ module Gc = Stdlib.Gc
 There is not equivalent functionality in Base or Stdio at the moment,
 so you need to use [Caml.Gc] instead"]
 
-module Genlex = Stdlib.Genlex 
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Genlex instead"]
-
 module Hashtbl = Stdlib.Hashtbl 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1214,6 +1230,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Hashtbl instead"]
 
+module In_channel = Stdlib.In_channel 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.In_channel instead"]
+
 module Int = Stdlib.Int 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1284,6 +1307,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.MoreLabels instead"]
 
+module Mutex = Stdlib.Mutex 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Mutex instead"]
+
 module Nativeint = Stdlib.Nativeint 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1312,6 +1342,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Option instead"]
 
+module Out_channel = Stdlib.Out_channel 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Out_channel instead"]
+
 module Parsing = Stdlib.Parsing 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1319,13 +1356,6 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Parsing instead"]
 
-module Pervasives = Stdlib.Pervasives 
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Pervasives instead"]
-
 module Printexc = Stdlib.Printexc 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1366,6 +1396,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Scanf instead"]
 
+module Semaphore = Stdlib.Semaphore 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Semaphore instead"]
+
 module Seq = Stdlib.Seq 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1395,13 +1432,6 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.StdLabels instead"]
 
-module Stream = Stdlib.Stream 
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Stream instead"]
-
 module String = Stdlib.String 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1444,25 +1474,3 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Weak instead"]
 
-module In_channel : sig end
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.In_channel instead"]
-
-module Out_channel : sig end
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Out_channel instead"]
-
-exception Not_found
-[@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Instead of raising [Not_found], consider using [raise_s] with an informative error
-message.  If code needs to distinguish [Not_found] from other exceptions, please change
-it to handle both [Not_found] and [Not_found_s].  Then, instead of raising [Not_found],
-raise [Not_found_s] with an informative error message."]
-
